@@ -419,7 +419,9 @@ def get_status_info_wom(delivery_order):
         )
         status = 'Orden Cancelada por Logística'
 
-    elif delivery_order['status'] == DeliveryOrderStatusType.B2CTraveling.value:
+
+    elif delivery_order['status'] in [DeliveryOrderStatusType.B2CTraveling.value,
+                                      DeliveryOrderStatusType.DeliveryCourierReceived.value]:
         events_info = filter(
             lambda x: x['status'] == delivery_order['status'],
             delivery_order['events_info']
@@ -558,17 +560,6 @@ def get_status_info(delivery_order):
         description_dic = get_delivery_order_status_description_dic()
         description = description_dic[delivery_order['status']]
 
-    elif delivery_order['status'] == DeliveryOrderStatusType.DeliveryCourierReceived.value:
-        events_info = filter(
-            lambda x: x['status'] == delivery_order['status'],
-            delivery_order['events_info']
-        )
-        status_dic = get_delivery_order_status_dic()
-        status = status_dic[delivery_order['status']]
-
-        description_dic = get_delivery_order_status_description_dic()
-        description = description_dic[delivery_order['status']]
-
     elif delivery_order['status'] == DeliveryOrderStatusType.DeliveryConfirmed.value:
         events_info = filter(
             lambda x: x['status'] == delivery_order['status'],
@@ -600,7 +591,7 @@ def get_status_info(delivery_order):
         description_dic = get_delivery_order_status_description_dic()
         description = description_dic[delivery_order['status']]
 
-    elif delivery_order['status'] == DeliveryOrderStatusType.B2CTraveling.value:
+    elif delivery_order['status'] in [DeliveryOrderStatusType.B2CTraveling.value, DeliveryOrderStatusType.DeliveryCourierReceived.value]:
         events_info = filter(
             lambda x: x['status'] == delivery_order['status'],
             delivery_order['events_info']
@@ -621,7 +612,7 @@ def get_status_info(delivery_order):
         description_dic = get_delivery_order_status_description_dic()
         description = description_dic[delivery_order['status']]
 
-    elif delivery_order['status'] == DeliveryOrderStatusType.Delivered.value:
+    elif DeliveryOrderStatusType.Delivered.value == DeliveryOrderStatusType.Delivered.value:
         events_info = filter(
             lambda x: x['status'] == DeliveryOrderStatusType.Delivered.value,
             delivery_order['events_info']
